@@ -47,8 +47,8 @@
 
 int main(int argc, char **argv)
 {
-    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QApplication app(argc, argv);
+    KLocalizedString::setApplicationDomain("koko");
     app.setApplicationDisplayName("Koko");
     app.setOrganizationDomain("kde.org");
 
@@ -61,6 +61,7 @@ int main(int argc, char **argv)
 
     aboutData.setOrganizationDomain(QByteArray("kde.org"));
     aboutData.setProductName(QByteArray("koko"));
+    aboutData.setBugAddress("https://bugs.kde.org/describecomponents.cgi?product=koko");
 
     aboutData.addAuthor(xi18nc("@info:credit", "Vishesh Handa"), xi18nc("@info:credit", "Developer"), "vhanda@kde.org");
 
@@ -185,7 +186,6 @@ int main(int argc, char **argv)
     engine.rootContext()->setContextProperty("kokoConfig", &config);
     engine.rootContext()->setContextProperty(QStringLiteral("kokoAboutData"), QVariant::fromValue(aboutData));
 
-    QString path;
     // we want different main files on desktop or mobile
     // very small difference as they as they are subclasses of the same thing
     engine.load(QUrl(QStringLiteral("qrc:/qml/Main.qml")));
